ribs_units library

Type-safe physical quantities and units of measure for Dart.

Provides strongly typed dimension classes (e.g., Length, Mass, Time) and operations to safely convert and compute physical quantities.

Classes

Acceleration
A quantity representing linear acceleration.
AccelerationUnit
Base class for all Acceleration units.
Acres
Acres.
AmpereHours
Ampere-hours (Ah) — 3 600 coulombs; used for battery capacity.
Amperes
Amperes (A) — the SI base unit of electric current.
Angle
A quantity representing a plane angle.
AngleUnit
Base class for all Angle units.
AngularRevolutionsPerMinute
Revolutions per minute (rpm).
AngularVelocity
A quantity representing angular velocity (rate of change of angle).
AngularVelocityUnit
Base class for all AngularVelocity units.
Arcminutes
Arcminutes (amin) — 1/60 of a degree.
Arcseconds
Arcseconds (asec) — 1/60 of an arcminute.
Area
A quantity representing a two-dimensional area.
AreaDensity
A quantity representing areal (surface) mass density (mass per unit area).
AreaDensityUnit
Base class for all AreaDensity units.
AreaUnit
Base class for all Area units.
Atmospheres
Standard atmospheres (atm ≈ 101 325 Pa).
Barnes
Barns (b) — 10⁻²⁸ m², used in nuclear and particle physics cross-sections.
Bars
Bars (100 000 Pa).
BaseUnit<A extends Quantity<A>>
A concrete, immutable UnitConverter with a fixed unit name, symbol, and conversionFactor.
BinarySystem
IEC binary prefix multipliers (powers of 1024).
Bits
Bits (bit) — 1/8 of a byte; the smallest unit of information.
BitsPerSecond
Bits per second (bps).
BritishThermalUnits
British Thermal Units (BTU).
BtuPerFahrenheit
British Thermal Units per degree Fahrenheit (BTU/°F).
BtuPerHour
BTU per hour (BTU/hr).
Bytes
Bytes (B) — the SI base unit of information.
BytesPerSecond
Bytes per second (B/s) — the base unit of data rate.
Calories
Thermochemical calories (cal).
Candelas
Candelas (cd) — the SI base unit of luminous intensity.
Capacitance
A quantity representing electrical capacitance.
CapacitanceUnit
Base class for all Capacitance units.
Carats
Carats (ct) — used for gemstones; 1 ct = 200 mg.
Celsius
The Celsius temperature scale (°C).
Centilitres
Centilitres (cl).
Centimeters
Centimeters (cm).
ChemicalAmount
A quantity representing amount of chemical substance.
ChemicalAmountUnit
Base class for all ChemicalAmount units.
Coulombs
Coulombs (C) — the SI unit of electric charge.
CubicFeet
Cubic feet (ft³).
CubicFeetPerMinute
Cubic feet per minute (ft³/min).
CubicFeetPerSecond
Cubic feet per second (ft³/s).
CubicInches
Cubic inches (in³).
CubicMeters
Cubic meters (m³) — the SI unit of volume.
CubicMetersPerSecond
Cubic meters per second (m³/s).
CubicUsMiles
Cubic US miles (mi³).
CubicYards
Cubic yards (yd³).
Dalton
Daltons (Da) — atomic mass unit; 1 Da ≈ 1.66054 × 10⁻²⁷ kg.
DataRate
A quantity representing data rate (throughput) — the amount of digital information transferred per second.
DataRateUnit
Base class for all DataRate units.
Days
Days (d).
Decameters
Decameters (dam).
Deciamperes
Deciamperes (dA).
Decilitres
Decilitres (dl).
Decimeters
Decimeters (dm).
Degrees
Degrees (°) — 1/360 of a full rotation.
DegreesPerSecond
Degrees per second (°/s).
Density
A quantity representing volumetric mass density (mass per unit volume).
DensityUnit
Base class for all Density units.
Dozens
Dozens (dz) — 12 items.
Dynes
Dynes (dyn) — the CGS unit of force (10⁻⁵ N).
Each
A dimensionless quantity representing a count of discrete items.
Eaches
Individual items (each).
EachUnit
Base class for all Each units.
EarthGravities
Standard Earth gravity (g ≈ 9.80665 m/s²).
ElectricCharge
A quantity representing electric charge.
ElectricChargeUnit
Base class for all ElectricCharge units.
ElectricConductance
A quantity representing electrical conductance (the reciprocal of resistance).
ElectricConductanceUnit
Base class for all ElectricConductance units.
ElectricCurrent
A quantity representing electric current.
ElectricCurrentUnit
Base class for all ElectricCurrent units.
ElectricPotential
A quantity representing electric potential (voltage).
ElectricPotentialUnit
Base class for all ElectricPotential units.
ElectricResistance
A quantity representing electrical resistance.
ElectricResistanceUnit
Base class for all ElectricResistance units.
Electronvolts
Electronvolts (eV).
Energy
A quantity representing energy or work.
EnergyUnit
Base class for all Energy units.
ErgsPerSecond
Ergs per second (erg/s) — the CGS unit of power (10⁻⁷ W).
ErgsPerSecondPerSquareCentimeter
Ergs per second per square centimeter (erg/s/cm²).
Exabits
Exabits (Ebit) — 10¹⁸ bits.
ExabitsPerSecond
Exabits per second (Ebps) — 10¹⁸ bps.
Exabytes
Exabytes (EB) — 10¹⁸ bytes.
ExabytesPerSecond
Exabytes per second (EB/s) — 10¹⁸ B/s.
Exbibits
Exbibits (Eibit) — 2⁶⁰ bits (IEC binary prefix).
ExbibitsPerSecond
Exbibits per second (Eibps) — 2⁶⁰ bps (IEC binary prefix).
Exbibytes
Exbibytes (EiB) — 2⁶⁰ bytes (IEC binary prefix).
ExbibytesPerSecond
Exbibytes per second (EiB/s) — 2⁶⁰ B/s (IEC binary prefix).
Fahrenheit
The Fahrenheit temperature scale (°F).
Farads
Farads (F) — the SI unit of capacitance.
Feet
Feet (ft).
FeetPerSecond
Feet per second (ft/s).
FeetPerSecondSquared
Feet per second squared (ft/s²).
Femtofarads
Femtofarads (fF).
FluidOunces
Fluid ounces (oz) — one 128th of a US gallon.
Footcandles
Footcandles (fc) — lumens per square foot.
Footlamberts
Footlamberts (fL).
Force
A quantity representing force.
ForceUnit
Base class for all Force units.
Frequency
A quantity representing frequency (cycles or events per unit time).
FrequencyUnit
Base class for all Frequency units.
GallonsPerMinute
US gallons per minute (gal/min).
Gauss
Gauss (G) — the CGS unit of magnetic flux density (1 G = 10⁻⁴ T).
Gibibits
Gibibits (Gibit) — 2³⁰ bits (IEC binary prefix).
GibibitsPerSecond
Gibibits per second (Gibps) — 2³⁰ bps (IEC binary prefix).
Gibibytes
Gibibytes (GiB) — 2³⁰ bytes (IEC binary prefix).
GibibytesPerSecond
Gibibytes per second (GiB/s) — 2³⁰ B/s (IEC binary prefix).
Gigabits
Gigabits (Gbit) — 10⁹ bits.
GigabitsPerSecond
Gigabits per second (Gbps) — 10⁹ bps.
Gigabytes
Gigabytes (GB) — 10⁹ bytes.
GigabytesPerSecond
Gigabytes per second (GB/s) — 10⁹ B/s.
Gigahertz
Gigahertz (GHz).
Gigajoules
Gigajoules (GJ).
Gigaohms
Gigaohms (GΩ).
Gigapascals
Gigapascals (GPa).
GigawattHours
Gigawatt-hours (GWh).
Gigawatts
Gigawatts (GW).
Gradians
Gradians (grad) — 1/400 of a full rotation.
Grams
Grams (g).
GramsPerCubicCentimeter
Grams per cubic centimeter (g/cm³) — also known as specific gravity relative to water.
GramsPerSecond
Grams per second (g/s).
GramsPerSquareCentimeter
Grams per square centimeter (g/cm²).
GreatGross
Great gross (gg) — 1 728 items (12 gross).
Gross
Gross (gr) — 144 items (12 dozen).
Hectares
Hectares (ha).
Hectolitres
Hectolitres (hl).
Hectometers
Hectometers (hm).
Henries
Henries (H) — the SI unit of inductance.
Hertz
Hertz (Hz) — the SI unit of frequency.
Horsepower
Mechanical horsepower (hp ≈ 745.7 W).
Hours
Hours (h).
Illuminance
A quantity representing illuminance — the total luminous flux incident on a surface per unit area.
IlluminanceUnit
Base class for all Illuminance units.
Inches
Inches (in).
Inductance
A quantity representing electrical inductance.
InductanceUnit
Base class for all Inductance units.
Information
A quantity representing digital information — measured in bytes or bits, with both metric (SI) and binary (IEC) prefix variants.
InformationUnit
Base class for all Information units.
Irradiance
A quantity representing irradiance — the radiant flux received per unit area.
IrradianceUnit
Base class for all Irradiance units.
Joules
Joules (J) — the SI unit of energy.
JoulesPerKelvin
Joules per kelvin (J/K) — the SI unit of thermal capacity.
Kelvin
The Kelvin temperature scale (K).
Kibibits
Kibibits (Kibit) — 2¹⁰ bits (IEC binary prefix).
KibibitsPerSecond
Kibibits per second (Kibps) — 2¹⁰ bps (IEC binary prefix).
Kibibytes
Kibibytes (KiB) — 2¹⁰ = 1 024 bytes (IEC binary prefix).
KibibytesPerSecond
Kibibytes per second (KiB/s) — 2¹⁰ B/s (IEC binary prefix).
Kiloamperes
Kiloamperes (kA).
Kilobits
Kilobits (Kbit) — 10³ bits.
KilobitsPerSecond
Kilobits per second (Kbps) — 10³ bps.
Kilobytes
Kilobytes (KB) — 10³ bytes.
KilobytesPerSecond
Kilobytes per second (KB/s) — 10³ B/s.
Kilocalories
Kilocalories (kcal) — the "food calorie".
Kilograms
Kilograms (kg) — the SI base unit of mass.
KilogramsPerCubicFoot
Kilograms per cubic foot (kg/ft³).
KilogramsPerCubicMeter
Kilograms per cubic meter (kg/m³) — the SI unit of density.
KilogramsPerHour
Kilograms per hour (kg/h).
KilogramsPerLiter
Kilograms per liter (kg/L).
KilogramsPerMinute
Kilograms per minute (kg/min).
KilogramsPerSecond
Kilograms per second (kg/s).
KilogramsPerSquareMeter
Kilograms per square meter (kg/m²).
Kilohertz
Kilohertz (kHz).
Kilojoules
Kilojoules (kJ).
Kilolux
Kilolux (klx).
Kilometers
Kilometers (km).
KilometersPerHour
Kilometers per hour (km/h).
KilometersPerSecond
Kilometers per second (km/s).
Kilomoles
Kilomoles (kmol).
Kilonewtons
Kilonewtons (kN).
Kiloohms
Kiloohms (kΩ).
Kilopascals
Kilopascals (kPa).
Kiloponds
Kiloponds (kp) — force exerted by a mass of 1 kg under standard gravity.
Kilopounds
Kilopounds (klb).
KilopoundsPerHour
Kilopounds per hour (klb/h).
Kilovolts
Kilovolts (kV).
KilowattHours
Kilowatt-hours (kWh).
Kilowatts
Kilowatts (kW).
Kips
Kips (kip) — 1 000 pounds-force.
Knots
Knots (kn) — nautical miles per hour.
Lamberts
Lamberts (L).
Length
A quantity representing length or distance.
LengthUnit
Base class for all Length units.
LitersPerHour
Liters per hour (L/h).
LitersPerMinute
Liters per minute (L/min).
LitersPerSecond
Liters per second (L/s).
Litres
Litres (L).
Lumens
Lumens (lm) — the SI unit of luminous flux.
Luminance
A quantity representing luminance — the luminous intensity per unit area of a surface emitting or reflecting light in a given direction.
LuminanceUnit
Base class for all Luminance units.
LuminousFlux
A quantity representing luminous flux — the total perceived power of light emitted by a source, weighted by the human visual response.
LuminousFluxUnit
Base class for all LuminousFlux units.
LuminousIntensity
A quantity representing luminous intensity — the luminous flux emitted per unit solid angle in a given direction.
LuminousIntensityUnit
Base class for all LuminousIntensity units.
Lux
Lux (lx) — the SI unit of illuminance.
MagneticFlux
A quantity representing magnetic flux.
MagneticFluxDensity
A quantity representing magnetic flux density (magnetic field strength).
MagneticFluxDensityUnit
Base class for all MagneticFluxDensity units.
MagneticFluxUnit
Base class for all MagneticFlux units.
Mass
A quantity representing mass.
MassFlow
A quantity representing mass flow rate (mass per unit time).
MassFlowUnit
Base class for all MassFlow units.
MassUnit
Base class for all Mass units.
Mebibits
Mebibits (Mibit) — 2²⁰ bits (IEC binary prefix).
MebibitsPerSecond
Mebibits per second (Mibps) — 2²⁰ bps (IEC binary prefix).
Mebibytes
Mebibytes (MiB) — 2²⁰ bytes (IEC binary prefix).
MebibytesPerSecond
Mebibytes per second (MiB/s) — 2²⁰ B/s (IEC binary prefix).
Megabits
Megabits (Mbit) — 10⁶ bits.
MegabitsPerSecond
Megabits per second (Mbps) — 10⁶ bps.
Megabytes
Megabytes (MB) — 10⁶ bytes.
MegabytesPerSecond
Megabytes per second (MB/s) — 10⁶ B/s.
Megahertz
Megahertz (MHz).
Megajoules
Megajoules (MJ).
Megamoles
Megamoles (Mmol).
Meganewtons
Meganewtons (MN).
Megaohms
Megaohms (MΩ).
Megapascals
Megapascals (MPa).
Megapounds
Megapounds (Mlb).
MegapoundsPerHour
Megapounds per hour (Mlb/h).
Megavolts
Megavolts (MV).
MegawattHours
Megawatt-hours (MWh).
Megawatts
Megawatts (MW).
Meters
Meters (m) — the SI base unit of length.
MetersPerSecond
Meters per second (m/s) — the SI unit of velocity.
MetersPerSecondSquared
Meters per second squared (m/s²) — the SI unit of acceleration.
MetricSystem
SI metric prefix multipliers.
Microamperes
Microamperes (µA).
Microcandelas
Microcandelas (µcd).
Microfarads
Microfarads (µF).
Micrograms
Micrograms (mcg).
Microhenries
Microhenries (µH).
MicrolitersPerSecond
Microliters per second (µL/s).
Microlitres
Microlitres (µl).
Microlumens
Microlumens (µlm).
Micromoles
Micromoles (µmol).
Micronewtons
Micronewtons (µN).
Microns
Microns / micrometers (µm).
Microohms
Microohms (µΩ).
Microseconds
Microseconds (µs).
Microsiemens
Microsiemens (µS).
Microteslas
Microteslas (µT).
Microvolts
Microvolts (μV).
Microwebers
Microwebers (µWb).
MilliampereHours
Milliampere-hours (mAh) — 3.6 coulombs; used for small battery capacity.
Milliamperes
Milliamperes (mA).
Millibars
Millibars (mbar).
Millicandelas
Millicandelas (mcd).
Millifarads
Millifarads (mF).
Milligrams
Milligrams (mg).
Millihenries
Millihenries (mH).
Millijoules
Millijoules (mJ).
MillilitersPerHour
Milliliters per hour (mL/h).
MillilitersPerMinute
Milliliters per minute (mL/min).
MillilitersPerSecond
Milliliters per second (mL/s).
Millilitres
Millilitres (ml).
Millilumens
Millilumens (mlm).
Millilux
Millilux (mlx).
Millimeters
Millimeters (mm).
MillimetersPerSecond
Millimeters per second (mm/s).
Millimoles
Millimoles (mmol).
Millinewtons
Millinewtons (mN).
Milliohms
Milliohms (mΩ).
Milliseconds
Milliseconds (ms) — the internal base unit for Time.
Millisiemens
Millisiemens (mS).
Millisteradians
Millisteradians (msr).
Milliteslas
Milliteslas (mT).
Millivolts
Millivolts (mV).
Milliwatts
Milliwatts (mW).
MilliwattsPerMeter
Milliwatts per meter (mW/m).
MilliwattsPerSquareMeter
Milliwatts per square meter (mW/m²).
MilliwattsPerSteradian
Milliwatts per steradian (mW/sr).
MilliwattsPerSteradianPerMeter
Milliwatts per steradian per meter (mW/sr/m).
MilliwattsPerSteradianPerSquareMeter
Milliwatts per steradian per square meter (mW/sr/m²).
Milliwebers
Milliwebers (mWb).
Minutes
Minutes (min).
Moles
Moles (mol) — the SI base unit of amount of substance.
Momentum
A quantity representing linear momentum (mass × velocity).
MomentumUnit
Base class for all Momentum units.
Nanofarads
Nanofarads (nF).
Nanograms
Nanograms (ng).
Nanohenries
Nanohenries (nH).
NanolitersPerSecond
Nanoliters per second (nL/s).
Nanolitres
Nanolitres (nl).
Nanometers
Nanometers (nm).
Nanomoles
Nanomoles (nmol).
Nanoseconds
Nanoseconds (ns).
Nanoteslas
Nanoteslas (nT).
NauticalMiles
Nautical miles (nmi).
Newtons
Newtons (N) — the SI unit of force.
NewtonSeconds
Newton-seconds (N·s) — the SI unit of momentum.
Nits
Nits (cd/m²) — the SI unit of luminance.
Octets
Octets (o) — equivalent to bytes; used in networking standards.
Ohms
Ohms (Ω) — the SI unit of electrical resistance.
Ounces
Ounces (oz) — avoirdupois.
Pascals
Pascals (Pa) — the SI unit of pressure.
Pebibits
Pebibits (Pibit) — 2⁵⁰ bits (IEC binary prefix).
PebibitsPerSecond
Pebibits per second (Pibps) — 2⁵⁰ bps (IEC binary prefix).
Pebibytes
Pebibytes (PiB) — 2⁵⁰ bytes (IEC binary prefix).
PebibytesPerSecond
Pebibytes per second (PiB/s) — 2⁵⁰ B/s (IEC binary prefix).
Pennyweights
Pennyweights (dwt) — 24 troy grains.
Petabits
Petabits (Pbit) — 10¹⁵ bits.
PetabitsPerSecond
Petabits per second (Pbps) — 10¹⁵ bps.
Petabytes
Petabytes (PB) — 10¹⁵ bytes.
PetabytesPerSecond
Petabytes per second (PB/s) — 10¹⁵ B/s.
Picofarads
Picofarads (pF).
Picohenries
Picohenries (pH).
Picosiemens
Picosiemens (pS).
Poundals
Poundals (pdl).
PoundForceSeconds
Pound-force-seconds (lbf·s).
Pounds
Pounds (lb) — avoirdupois.
PoundsForce
Pounds-force (lbf).
PoundsPerCubicFoot
Pounds per cubic foot (lb/ft³).
PoundsPerCubicInch
Pounds per cubic inch (lb/in³).
PoundsPerHour
Pounds per hour (lb/h).
PoundsPerMinute
Pounds per minute (lb/min).
PoundsPerSecond
Pounds per second (lb/s).
PoundsPerSquareFoot
Pounds per square foot (lb/ft²).
PoundsPerSquareInch
Pounds per square inch (psi).
Power
A quantity representing power (energy per unit time).
PowerUnit
Base class for all Power units.
Pressure
A quantity representing pressure (force per unit area).
PressureUnit
Base class for all Pressure units.
Quantity<A extends Quantity<A>>
Base class for all typed physical quantities in ribs_units.
Radiance
A quantity representing radiance — the radiant flux emitted, reflected, or received per unit solid angle per unit projected area.
RadianceUnit
Base class for all Radiance units.
Radians
Radians (rad) — the SI unit of plane angle.
RadiansPerHour
Radians per hour (rad/h).
RadiansPerMinute
Radians per minute (rad/min).
RadiansPerSecond
Radians per second (rad/s) — the SI unit of angular velocity.
RadiantIntensity
A quantity representing radiant intensity — the radiant flux emitted per unit solid angle in a given direction.
RadiantIntensityUnit
Base class for all RadiantIntensity units.
Rankine
The Rankine temperature scale (°R).
RevolutionsPerMinute
Revolutions per minute (rpm).
RevolutionsPerSecond
Revolutions per second (rev/s).
Scores
Scores — 20 items.
Seconds
Seconds (s).
Siemens
Siemens (S) — the SI unit of electrical conductance.
SolarLuminosities
Solar luminosities (L☉ ≈ 3.828 × 10²⁶ W).
SolidAngle
A quantity representing a solid angle (the 3-D analogue of a plane angle).
SolidAngleUnit
Base class for all SolidAngle units.
SpectralIntensity
A quantity representing spectral intensity — radiant intensity per unit wavelength interval.
SpectralIntensityUnit
Base class for all SpectralIntensity units.
SpectralPower
A quantity representing spectral power — radiant flux per unit wavelength interval.
SpectralPowerUnit
Base class for all SpectralPower units.
SquareCentimeters
Square centimeters (cm²).
SquareDegrees
Square degrees (deg²).
SquareFeet
Square feet (ft²).
SquareInches
Square inches (in²).
SquareKilometers
Square kilometers (km²).
SquareMeters
Square meters (m²) — the SI unit of area.
SquareUsMiles
Square US miles (mi²).
SquareYards
Square yards (yd²).
Steradians
Steradians (sr) — the SI unit of solid angle.
Stilbs
Stilbs (sb) — CGS unit of luminance; 1 sb = 10 000 cd/m².
Stone
Stone (st) — 14 avoirdupois pounds.
Tablespoons
Tablespoons (tbsp) — one half of a fluid ounce.
Teaspoons
Teaspoons (tsp) — one third of a tablespoon.
Tebibits
Tebibits (Tibit) — 2⁴⁰ bits (IEC binary prefix).
TebibitsPerSecond
Tebibits per second (Tibps) — 2⁴⁰ bps (IEC binary prefix).
Tebibytes
Tebibytes (TiB) — 2⁴⁰ bytes (IEC binary prefix).
TebibytesPerSecond
Tebibytes per second (TiB/s) — 2⁴⁰ B/s (IEC binary prefix).
Temperature
A quantity representing temperature.
TemperatureConversions
Low-level temperature conversion formulas.
TemperatureScale
Base class for temperature scale units.
Terabits
Terabits (Tbit) — 10¹² bits.
TerabitsPerSecond
Terabits per second (Tbps) — 10¹² bps.
Terabytes
Terabytes (TB) — 10¹² bytes.
TerabytesPerSecond
Terabytes per second (TB/s) — 10¹² B/s.
Terahertz
Terahertz (THz).
Terajoules
Terajoules (TJ).
Terawatts
Terawatts (TW).
Teslas
Teslas (T) — the SI unit of magnetic flux density.
ThermalCapacity
A quantity representing thermal capacity (heat capacity), i.e. the amount of energy required to raise a system's temperature by one degree.
ThermalCapacityUnit
Base class for all ThermalCapacity units.
Time
A quantity representing a duration of time.
TimeUnit
Base class for all Time units.
Tolas
Tolas — a traditional South Asian unit of mass; 180 troy grains.
Tonnes
Metric tonnes (t) — 1 000 kg.
Torr
Torr (≈ 133.322 Pa) — 1/760 of a standard atmosphere.
TroyGrains
Troy grains (gr) — the smallest unit in the troy weight system.
TroyOunces
Troy ounces (oz t) — used for precious metals; 480 troy grains.
TroyPounds
Troy pounds (lb t) — 12 troy ounces.
Turns
Turns — one full rotation (2π radians).
UnitConverter<A extends Quantity<A>>
A UnitOfMeasure whose conversion is a simple multiplicative factor.
UnitOfMeasure<A extends Quantity<A>>
Abstract base for all units of measure.
UsCups
US cups (c) — one sixteenth of a US gallon.
UsGallons
US gallons (gal).
UsMiles
US survey miles (mi).
UsMilesPerHour
US miles per hour (mph).
UsPints
US pints (pt) — one eighth of a US gallon.
UsQuarts
US quarts (qt) — one quarter of a US gallon.
Velocity
A quantity representing linear velocity (speed in a given direction).
VelocityUnit
Base class for all Velocity units.
Volts
Volts (V) — the SI unit of electric potential.
Volume
A quantity representing three-dimensional volume.
VolumeFlow
A quantity representing volumetric flow rate (volume per unit time).
VolumeFlowUnit
Base class for all VolumeFlow units.
VolumeUnit
Base class for all Volume units.
WattHours
Watt-hours (Wh).
Watts
Watts (W) — the SI unit of power.
WattsPerMeter
Watts per meter (W/m).
WattsPerSquareMeter
Watts per square meter (W/m²) — the SI unit of irradiance.
WattsPerSteradian
Watts per steradian (W/sr).
WattsPerSteradianPerMeter
Watts per steradian per meter (W/sr/m).
WattsPerSteradianPerSquareMeter
Watts per steradian per square meter (W/sr/m²) — the SI unit of radiance.
Webers
Webers (Wb) — the SI unit of magnetic flux.
Yards
Yards (yd).
Yobibits
Yobibits (Yibit) — 2⁸⁰ bits (IEC binary prefix).
YobibitsPerSecond
Yobibits per second (Yibps) — 2⁸⁰ bps (IEC binary prefix).
Yobibytes
Yobibytes (YiB) — 2⁸⁰ bytes (IEC binary prefix).
YobibytesPerSecond
Yobibytes per second (YiB/s) — 2⁸⁰ B/s (IEC binary prefix).
Yottabits
Yottabits (Ybit) — 10²⁴ bits.
YottabitsPerSecond
Yottabits per second (Ybps) — 10²⁴ bps.
Yottabytes
Yottabytes (YB) — 10²⁴ bytes.
YottabytesPerSecond
Yottabytes per second (YB/s) — 10²⁴ B/s.
Zebibits
Zebibits (Zibit) — 2⁷⁰ bits (IEC binary prefix).
ZebibitsPerSecond
Zebibits per second (Zibps) — 2⁷⁰ bps (IEC binary prefix).
Zebibytes
Zebibytes (ZiB) — 2⁷⁰ bytes (IEC binary prefix).
ZebibytesPerSecond
Zebibytes per second (ZiB/s) — 2⁷⁰ B/s (IEC binary prefix).
Zettabits
Zettabits (Zbit) — 10²¹ bits.
ZettabitsPerSecond
Zettabits per second (Zbps) — 10²¹ bps.
Zettabytes
Zettabytes (ZB) — 10²¹ bytes.
ZettabytesPerSecond
Zettabytes per second (ZB/s) — 10²¹ B/s.

Extensions

AccelerationOps on num
Extension methods for constructing Acceleration values from num.
AngleOps on num
Extension methods for constructing Angle values from num.
AngularVelocityOps on num
Extension methods for constructing AngularVelocity values from num.
AreaDensityOps on num
Extension methods for constructing AreaDensity values from num.
AreaOps on num
Extension methods for constructing Area values from num.
CapacitanceOps on num
Extension methods for constructing Capacitance values from num.
ChemicalAmountOps on num
Extension methods for constructing ChemicalAmount values from num.
DataRateOps on num
Extension methods for constructing DataRate values from num.
DensityOps on num
Extension methods for constructing Density values from num.
EachOps on num
Extension methods for constructing Each values from num.
ElectricChargeOps on num
Extension methods for constructing ElectricCharge values from num.
ElectricConductanceOps on num
Extension methods for constructing ElectricConductance values from num.
ElectricCurrentOps on num
Extension methods for constructing ElectricCurrent values from num.
ElectricPotentialOps on num
Extension methods for constructing ElectricPotential values from num.
ElectricResistanceOps on num
Extension methods for constructing ElectricResistance values from num.
EnergyOps on num
Extension methods for constructing Energy values from num.
ForceOps on num
Extension methods for constructing Force values from num.
FrequencyOps on num
Extension methods for constructing Frequency values from num.
IlluminanceOps on num
Extension methods for constructing Illuminance values from num.
InductanceOps on num
Extension methods for constructing Inductance values from num.
InformationOps on num
Extension methods for constructing Information values from num.
IrradianceOps on num
Extension methods for constructing Irradiance values from num.
LengthOps on num
Extension methods for constructing Length values from num.
LuminanceOps on num
Extension methods for constructing Luminance values from num.
LuminousFluxOps on num
Extension methods for constructing LuminousFlux values from num.
LuminousIntensityOps on num
Extension methods for constructing LuminousIntensity values from num.
MagneticFluxDensityOps on num
Extension methods for constructing MagneticFluxDensity values from num.
MagneticFluxOps on num
Extension methods for constructing MagneticFlux values from num.
MassFlowOps on num
Extension methods for constructing MassFlow values from num.
MassOps on num
Extension methods for constructing Mass values from num.
MomentumOps on num
Extension methods for constructing Momentum values from num.
PowerOps on num
Extension methods for constructing Power values from num.
PressureOps on num
Extension methods for constructing Pressure values from num.
RadianceOps on num
Extension methods for constructing Radiance values from num.
RadiantIntensityOps on num
Extension methods for constructing RadiantIntensity values from num.
SolidAngleOps on num
Extension methods for constructing SolidAngle values from num.
SpectralIntensityOps on num
Extension methods for constructing SpectralIntensity values from num.
SpectralPowerOps on num
Extension methods for constructing SpectralPower values from num.
TemperatureOps on num
Extension methods for constructing Temperature values from num.
ThermalCapacityOps on num
Extension methods for constructing ThermalCapacity values from num.
TimeOps on num
Extension methods for constructing Time values from num.
VelocityOps on num
Extension methods for constructing Velocity values from num.
VolumeFlowOps on num
Extension methods for constructing VolumeFlow values from num.
VolumeOps on num
Extension methods for constructing Volume values from num.