EachOps extension

Extension methods for constructing Each values from num.

on

Properties

dozen Each

Available on num, provided by the EachOps extension

Creates an Each of this value in dozens.
no setter
each Each

Available on num, provided by the EachOps extension

Creates an Each of this value as individual items.
no setter
greatGross Each

Available on num, provided by the EachOps extension

Creates an Each of this value in great gross.
no setter
gross Each

Available on num, provided by the EachOps extension

Creates an Each of this value in gross.
no setter
score Each

Available on num, provided by the EachOps extension

Creates an Each of this value in scores.
no setter