RadiantIntensityUnit class abstract
Base class for all RadiantIntensity units.
- Inheritance
-
- Object
- UnitOfMeasure<
RadiantIntensity> - UnitConverter<
RadiantIntensity> - BaseUnit<
RadiantIntensity> - RadiantIntensityUnit
- Implementers
Constructors
- RadiantIntensityUnit(String unit, String symbol, double conversionFactor)
-
const
Properties
- conversionFactor → double
-
The factor that converts a value in this unit to the internal base.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The display symbol for this unit (e.g.
'm','kg').finalinherited - unit → String
-
The canonical name of this unit (e.g.
'meter','kilogram').finalinherited
Methods
-
call(
num value) → RadiantIntensity -
Creates a quantity of
valueexpressed in this unit.override -
converterFrom(
double value) → double -
Converts
valueexpressed in this unit to the internal base value.inherited -
converterTo(
double value) → double -
Converts
valueexpressed in the internal base to this unit.inherited -
convertFrom(
num value) → double -
Convenience wrapper: converts
valuein this unit to the internal base.inherited -
convertTo(
num value) → double -
Convenience wrapper: converts
valueto this unit's representation from the internal base.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited