SolidAngle class final
A quantity representing a solid angle (the 3-D analogue of a plane angle).
- Inheritance
-
- Object
- Quantity<
SolidAngle> - SolidAngle
Constructors
-
SolidAngle(double value, UnitOfMeasure<
SolidAngle> unit)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toMillisteradians → SolidAngle
-
Converts this to millisteradians (msr).
no setter
- toSquareDegrees → SolidAngle
-
Converts this to square degrees (deg²).
no setter
- toSteradians → SolidAngle
-
Converts this to steradians (sr).
no setter
-
unit
→ UnitOfMeasure<
SolidAngle> -
The unit of measure that value is expressed in.
finalinherited
- value → double
-
The raw numeric value of this quantity expressed in unit.
finalinherited
Methods
-
equivalentTo(
Quantity< SolidAngle> other) → bool -
Returns true if this quantity represents the same physical magnitude as
other, regardless of which unit each is expressed in.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
to(
UnitOfMeasure< SolidAngle> uom) → double -
Converts this quantity to
uomand returns the raw double value.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator +(
SolidAngle that) → SolidAngle -
Returns the sum of this quantity and
that, expressed in unit.inherited -
operator -(
SolidAngle that) → SolidAngle -
Returns the difference of this quantity and
that, expressed in unit.inherited -
operator <(
SolidAngle that) → bool -
Returns true if this quantity is less than
that.inherited -
operator <=(
SolidAngle that) → bool -
Returns true if this quantity is less than or equal to
that.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
SolidAngle that) → bool -
Returns true if this quantity is greater than
that.inherited -
operator >=(
SolidAngle that) → bool -
Returns true if this quantity is greater than or equal to
that.inherited
Static Methods
-
parse(
String s) → Option< SolidAngle> -
Parses
sinto a SolidAngle, returningNoneif parsing fails.override
Constants
- millisteradians → const SolidAngleUnit
- Unit for millisteradians (msr).
- squareDegrees → const SolidAngleUnit
- Unit for square degrees (deg²).
- steradians → const SolidAngleUnit
- Unit for steradians (sr) — the SI unit of solid angle.
-
units
→ const Set<
SolidAngleUnit> - All supported SolidAngle units.