SpectralPower class final
A quantity representing spectral power — radiant flux per unit wavelength interval.
- Inheritance
-
- Object
- Quantity<
SpectralPower> - SpectralPower
Constructors
-
SpectralPower(double value, UnitOfMeasure<
SpectralPower> unit)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toMilliwattsPerMeter → SpectralPower
-
Converts this to milliwatts per meter (mW/m).
no setter
- toWattsPerMeter → SpectralPower
-
Converts this to watts per meter (W/m).
no setter
-
unit
→ UnitOfMeasure<
SpectralPower> -
The unit of measure that value is expressed in.
finalinherited
- value → double
-
The raw numeric value of this quantity expressed in unit.
finalinherited
Methods
-
equivalentTo(
Quantity< SpectralPower> other) → bool -
Returns true if this quantity represents the same physical magnitude as
other, regardless of which unit each is expressed in.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
to(
UnitOfMeasure< SpectralPower> uom) → double -
Converts this quantity to
uomand returns the raw double value.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator +(
SpectralPower that) → SpectralPower -
Returns the sum of this quantity and
that, expressed in unit.inherited -
operator -(
SpectralPower that) → SpectralPower -
Returns the difference of this quantity and
that, expressed in unit.inherited -
operator <(
SpectralPower that) → bool -
Returns true if this quantity is less than
that.inherited -
operator <=(
SpectralPower that) → bool -
Returns true if this quantity is less than or equal to
that.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
SpectralPower that) → bool -
Returns true if this quantity is greater than
that.inherited -
operator >=(
SpectralPower that) → bool -
Returns true if this quantity is greater than or equal to
that.inherited
Static Methods
-
parse(
String s) → Option< SpectralPower> -
Parses
sinto a SpectralPower, returningNoneif parsing fails.override
Constants
- milliwattsPerMeter → const SpectralPowerUnit
- Unit for milliwatts per meter (mW/m).
-
units
→ const Set<
SpectralPowerUnit> - All supported SpectralPower units.
- wattsPerMeter → const SpectralPowerUnit
- Unit for watts per meter (W/m).